@@ -19,8 +19,8 @@
 
 #include "richtextcomposertest.h"
 #include "../richtextcomposer.h"
-#include <qtest.h>
-#include <qsignalspy.h>
+#include <QTest>
+#include <QSignalSpy>
 #include <KCodecs/KCodecs>
 
 #include <KIconLoader>
@@ -28,7 +28,7 @@
 #include <QAction>
 
 #include <QTextCursor>
-#include <qtestevent.h>
+#include <QTestEvent>
 #include <QBuffer>
 #include <QTextBlock>
 #include <kpimtextedit/richtextcomposercontroler.h>
@@ -384,34 +384,34 @@ void RichTextComposerTest::testDeleteLine_data()
     QTest::addColumn<int>("cursorPos");
 
     QTest::newRow("delete1") << QStringLiteral("line1\nline2\nline3")
-                      << QStringLiteral("line1\nline3")
-                      << 6;
+                             << QStringLiteral("line1\nline3")
+                             << 6;
     QTest::newRow("delete2") << QStringLiteral("line1\nline2\nline3")
-                      << QStringLiteral("line2\nline3")
-                      << 5;
+                             << QStringLiteral("line2\nline3")
+                             << 5;
     QTest::newRow("delete3") << QStringLiteral("line1\nline2\nline3")
-                      << QStringLiteral("line1\nline3")
-                      << 11;
+                             << QStringLiteral("line1\nline3")
+                             << 11;
     QTest::newRow("delete4") << QStringLiteral("line1\nline2\nline3")
-                      << QStringLiteral("line2\nline3")
-                      << 0;
+                             << QStringLiteral("line2\nline3")
+                             << 0;
     QTest::newRow("delete5") << QStringLiteral("line1\nline2\nline3")
-                      << QStringLiteral("line1\nline2")
-                      << 17;
+                             << QStringLiteral("line1\nline2")
+                             << 17;
     QTest::newRow("delete6") << QStringLiteral("line1")
-                      << QString()
-                      << 0;
+                             << QString()
+                             << 0;
     QTest::newRow("delete7") << QStringLiteral("line1")
-                      << QString()
-                      << 5;
+                             << QString()
+                             << 5;
 
     // Now, test deletion with word wrapping. The line with the Ms is so long that it will get wrapped
     QTest::newRow("delete8") << QStringLiteral("line1\nMMMMMMM MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM\nline3")
-                      << QStringLiteral("line1\nMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM\nline3")
-                      << 6;
+                             << QStringLiteral("line1\nMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM\nline3")
+                             << 6;
     QTest::newRow("delete9") << QStringLiteral("line1\nMMMMMMM MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM\nline3")
-                      << QStringLiteral("line1\nMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM\nline3")
-                      << 13;
+                             << QStringLiteral("line1\nMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM\nline3")
+                             << 13;
 }
 
 void RichTextComposerTest::testDeleteLine()
