@@ -18,7 +18,10 @@
 */
 
 #include "emoticonlistwidgetselector.h"
-#include "emoticontexteditselector.h"
+#include <KEmoticons>
+#include <kemoticonstheme.h>
+// Use a static for this as calls to the KEmoticons constructor are expensive.
+Q_GLOBAL_STATIC(KEmoticons, sEmoticons)
 
 using namespace KPIMTextEdit;
 
@@ -59,9 +62,8 @@ QString EmoticonTextEditItem::pixmapPath() const
     return mPixmapPath;
 }
 
-
 EmoticonListWidgetSelector::EmoticonListWidgetSelector(QWidget *parent)
-    : QListWidget (parent)
+    : QListWidget(parent)
 {
     setViewMode(QListView::IconMode);
     setSelectionMode(QAbstractItemView::SingleSelection);
@@ -69,11 +71,14 @@ EmoticonListWidgetSelector::EmoticonListWidgetSelector(QWidget *parent)
     setDragEnabled(false);
     connect(this, &EmoticonListWidgetSelector::itemEntered, this, &EmoticonListWidgetSelector::slotMouseOverItem);
     connect(this, &EmoticonListWidgetSelector::itemClicked, this, &EmoticonListWidgetSelector::slotEmoticonClicked);
+    setIconSize(QSize(32, 32));
+    QFont f;
+    f.setPointSize(22);
+    setFont(f);
 }
 
 EmoticonListWidgetSelector::~EmoticonListWidgetSelector()
 {
-
 }
 
 void EmoticonListWidgetSelector::slotMouseOverItem(QListWidgetItem *item)
@@ -84,6 +89,36 @@ void EmoticonListWidgetSelector::slotMouseOverItem(QListWidgetItem *item)
     }
 }
 
+void EmoticonListWidgetSelector::loadEmotionsFromTheme()
+{
+    static QString cachedEmoticonsThemeName;
+    if (cachedEmoticonsThemeName.isEmpty()) {
+        cachedEmoticonsThemeName = KEmoticons::currentThemeName();
+    }
+    const QHash<QString, QStringList> list
+        = sEmoticons->theme(cachedEmoticonsThemeName).emoticonsMap();
+
+    //Keep in sync with linklocator.cpp
+    QStringList exclude;
+    exclude << QStringLiteral("(c)") << QStringLiteral("(C)") << QStringLiteral("&gt;:-(") << QStringLiteral("&gt;:(") << QStringLiteral("(B)") << QStringLiteral("(b)") << QStringLiteral("(P)")
+            << QStringLiteral("(p)");
+    exclude << QStringLiteral("(O)") << QStringLiteral("(o)") << QStringLiteral("(D)") << QStringLiteral("(d)") << QStringLiteral("(E)") << QStringLiteral("(e)") << QStringLiteral("(K)")
+            << QStringLiteral("(k)");
+    exclude << QStringLiteral("(I)") << QStringLiteral("(i)") << QStringLiteral("(L)") << QStringLiteral("(l)") << QStringLiteral("(8)") << QStringLiteral("(T)") << QStringLiteral("(t)")
+            << QStringLiteral("(G)");
+    exclude << QStringLiteral("(g)") << QStringLiteral("(F)") << QStringLiteral("(f)") << QStringLiteral("(H)");
+    exclude << QStringLiteral("8)") << QStringLiteral("(N)") << QStringLiteral("(n)") << QStringLiteral("(Y)") << QStringLiteral("(y)") << QStringLiteral("(U)") << QStringLiteral("(u)")
+            << QStringLiteral("(W)") << QStringLiteral("(w)");
+
+    const QHash<QString, QStringList>::const_iterator end = list.constEnd();
+    for (QHash<QString, QStringList>::const_iterator it = list.constBegin(); it != end; ++it) {
+        const QString str = it.value().first();
+        if (!exclude.contains(str)) {
+            new EmoticonTextEditItem(str, it.key(), this);
+        }
+    }
+}
+
 void EmoticonListWidgetSelector::setEmoticons(const QList<uint> &lst)
 {
     for (uint emoji : lst) {
@@ -101,4 +136,3 @@ void EmoticonListWidgetSelector::slotEmoticonClicked(QListWidgetItem *item)
 
     Q_EMIT itemSelected(itemEmoticon->text());
 }
-
